@@ -41,7 +41,7 @@ def _generate_swagger_spec():
   def _hotpatch_spec(spec):
     if isinstance(spec, dict):
       _hotpatch_spec_piece(spec)
-      for k, v in spec.iteritems():
+      for k, v in spec.items():
         _hotpatch_spec(v)
 
     elif isinstance(spec, list):
@@ -49,7 +49,7 @@ def _generate_swagger_spec():
         _hotpatch_spec(v)
 
     return spec
-  
+
   # Download the spec from dialpad.com.
   spec_json = requests.get('https://dialpad.com/static/openapi/apiv2openapi-en.json').json()
 
